var indexSectionsWithContent =
{
  0: "bdlw",
  1: "l",
  2: "l",
  3: "w",
  4: "w",
  5: "w",
  6: "lw",
  7: "bd"
};

var indexSectionNames =
{
  0: "all",
  1: "files",
  2: "functions",
  3: "typedefs",
  4: "enums",
  5: "enumvalues",
  6: "defines",
  7: "pages"
};

var indexSectionLabels =
{
  0: "All",
  1: "Files",
  2: "Functions",
  3: "Typedefs",
  4: "Enumerations",
  5: "Enumerator",
  6: "Macros",
  7: "Pages"
};

